==========================
CPUlib
==========================

A test Python module for educational purposes.

Usage
==========================

Example of running the project:

   .. code-block:: bash

	  from cpulib import *
      n = Numbers()
	  print(n.addition(2, 4))
	  
License
==========================

This project is licensed under the MIT License - see the `LICENSE` file for details.
